@@ -21,34 +21,44 @@ class Tool(enum.Enum):
     Instance = "instance"
 
 
-
 def random_color():
-    return ["#" + ''.join([random.choice('ABCDEF0123456789') for i in range(6)])]
+    return "#" + ''.join([random.choice('ABCDEF0123456789') for i in range(6)])
 
 
 class LabelOption:
-    def __init__(self, value, schemaId=uuid.uuid4().hex):
+    def __init__(self, value, schemaId=None):
         self.value = value,
-        self.schemaId = schemaId
+        if schemaId:
+            self.schemaId = schemaId
+        else:
+            self.schemaId = uuid.uuid4().hex
 
     def toDict(self):
         return self.__dict__
 
 
 class LabelCategory:
-    def __init__(self, tool: Tool, title="", required=False, schemaId=uuid.uuid4().hex,
-                 columnField=False, color=random_color(), shortcutKey=None, classifications=[], options=[]):
+    def __init__(self, tool: Tool, title="", required=False, schemaId=None,
+                 columnField=False, color=None, shortcutKey="", classifications=[], options=[]):
         self.tool = tool.value
-        self.titlr = title
+        self.title = title
         self.required = required
-        self.schemaId = schemaId
         self.columnField = columnField
         self.color = color
         self.shortcutKey = shortcutKey
         self.classifications = classifications
         self.options = options
+        if schemaId:
+            self.schemaId = schemaId
+        else:
+            self.schemaId = uuid.uuid4().hex
+        if color:
+            self.color = random_color()
+        else:
+            self.color = random_color()
 
     def toDict(self):
         d = self.__dict__
         d['classifications'] = list(map(lambda t: t.toDict(), self.classifications))
         d['options'] = list(map(lambda t: t.toDict(), self.options))
+        return d
