@@ -123,8 +123,12 @@ class SDK:
         response = requests.request("POST", url, headers=headers, data=payload)
         return response.json()
 
-    def get_assets(self, project_id, page=1, limit=10):
+    def get_assets(self, project_id, asset_id=None, external_id=None, page=1, limit=10):
         url = "%s/v2/project/%s/assets?page=%s&limit=%s" % (self.host,project_id, page, limit)
+        if asset_id:
+            url += "?_id=" % asset_id
+        if external_id:
+            url += "?externalId=" % external_id
 
         payload = {}
         headers = {
